package com.community.huiju.lisenter;

import com.community.commom.constant.Constant;
import com.community.huiju.event.MessageEvent;
import com.community.huiju.model.TpMessage;
import com.community.huiju.service.MessageServiceI;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;

/**
 * @author FXF
 * @date 2019-07-30
 */

@Component
@Slf4j
public class MessageLisenter {
	
	@Autowired
	private MessageServiceI tpMessageService;
	/**
	 * 推送消息
	 * @param event
	 */
	@EventListener
	public void pushMessage(MessageEvent event) {
		log.info("======推送消息======");
		switch (event.getType()){
			case Constant.ESTATE_RELATE_VERIFY_PASSED:
				tpMessageService.estateRelateVerifyPassed(event.getParamsMap());
				break;
			case Constant.ESTATE_RELATE_VERIFY_REJECTED:
				tpMessageService.estateRelateVerifyRejected(event.getParamsMap());
				break;
			case Constant.ESTATE_SERVICE_ANNOUNCEMENT_SUCCESS:
				break;
			case Constant.ESTATE_SERVICE_ACTIVITY_SUCCESS:
				break;
			case Constant.THREAD_REPLY:
				tpMessageService.threadReply(event.getParamsMap());
				break;
			case Constant.THREAD_REPORT:
				// 话题举报
				tpMessageService.threadReport(event.getParamsMap());
				break;
			case Constant.ACTIVITY_JOINED_DELETE_BY_ESTATE_SERVICE:
				break;
			case Constant.ACTIVITY_CANCELLED:
				break;
			case Constant.THREAD_CANCELLED:
				// 话题作废
				tpMessageService.threadCancelled(event.getParamsMap());
				break;
			case Constant.PUBLISH_BILL:
				break;
			case Constant.TICKET_REJECTED:
				// 工单拒绝处理
				tpMessageService.ticketRejected(event.getParamsMap());
				break;
			case Constant.TICKET_DISTRIBUTED:
				//工单受理分配
				tpMessageService.ticketDistributed(event.getParamsMap());
				break;
			case Constant.TICKET_SUBMIT_RESULT:
				// 工单处理结果
				tpMessageService.ticketSubmitResult(event.getParamsMap());
				break;
			case Constant.TICKET_REPLY:
				// 工单回复
				tpMessageService.ticketReply(event.getParamsMap());
				break;
			case Constant.SHOP_REVIEW_REPLY:
				break;
			case Constant.CUSTOMER_SUBMIT_VERIFY:
				// app户主自己审核
				tpMessageService.customerSubmitVerify(event.getParamsMap());
				break;
			case Constant.SYSTEM_MESSAGE:
				// 15条消息
				tpMessageService.systemMessage(event.getParamsMap());
				break;
			case Constant.CUSTOMER_SUBMIT_PROP_VERIFY:
				// 业主/家属/租客提交审核时推送物业端
				tpMessageService.customerSubmitPropVerify(event.getParamsMap());
				break;
			case Constant.ESTATE_SERVICE_ACTIVITY_SIGN_SUCCESS:
				// 业主/家属/租客 提交报名成功
				tpMessageService.estateServiceActivitySignSuccess(event.getParamsMap());
				break;
			case Constant.THREAD_ADD_TRANSACTION:
				// 添加帖子时推送物业端消息
				tpMessageService.threadAddTransaction(event.getParamsMap());
				break;
			case Constant.THREAD_REPORT_RROP:
				// 话题举报时推物业
				tpMessageService.threadReportProp(event.getParamsMap());
				break;
			case Constant.THREAD_UPDATE_TRANSACTION:
				// 话题修改时推物业
				tpMessageService.threadUpdateTransaction(event.getParamsMap());
				break;
			case Constant.TICKET_ADD:
				// app提交工单时推物业
				tpMessageService.ticketAdd(event.getParamsMap());
				break;
			case Constant.TICKET_TERMINATION:
				// app终止工单时推物业
				tpMessageService.ticketTermination(event.getParamsMap());
				break;
			case Constant.TICKET_UPDATE:
				// app工单修改时推物业
				tpMessageService.ticketUpdate(event.getParamsMap());
				break;
			case Constant.PAY_TYPE_SUCCEED:
				// 缴费成功时推物业
				tpMessageService.payTypeSucceed(event.getParamsMap());
				break;
			case Constant.PAY_MONTH_Bill_SUCCEED:
				// 月租车缴费成功时推送物业
				tpMessageService.payMonthBillSucceed(event.getParamsMap());
				break;
			case Constant.SHOP_REVIEW_PROP_REPLY:
				// 商铺评价时推送消息
				tpMessageService.shopReviewPropReply(event.getParamsMap());
				break;
			case Constant.TICKET_REPLY_PROP:
				// 工单回复app推物业
				tpMessageService.ticketReplyProp(event.getParamsMap());
				break;
			case Constant.TICKET_EVALUATE_PROP:
				// 工单回复app评价物业
				tpMessageService.ticketEvaluateProp(event.getParamsMap());
				break;
			default:
				break;
		}
		
	}
}
