package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.exception.WisdomException;
import com.community.huiju.feign.IHKServer;
import com.community.huiju.feign.entity.*;
import com.community.huiju.model.*;
import com.community.huiju.service.IEquipmentService;
import com.sun.org.apache.regexp.internal.RE;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Slf4j
@Service
public class EquipmentServiceImpl implements IEquipmentService {

    @Autowired
    private IHKServer ihkServer;

    private ResponseBean getResponseBean(String result){
        JSONObject jsonObject = JSONObject.parseObject(result);
        ResponseBean responseBean = jsonObject.toJavaObject(ResponseBean.class);
        if ("1".equals(responseBean.getCode())) {
            throw new WisdomException(responseBean.getMessage());
        }

        responseBean.addSuccess(jsonObject.getJSONObject("data").getInnerMap());
        return responseBean;
    }

    @Override
    public String pushPerson(TpEquipmentTree tpEquipmentTree, TpUnitHkSetting unitHkSetting, TaUser user, TaUserHk taUserHk, Integer expirationTime) {

        // 人员信息
        PushPerson.PersonBean personBean = new PushPerson.PersonBean();
        personBean.setAppkey(tpEquipmentTree.getAppkey());
        personBean.setSecret(tpEquipmentTree.getSecret());
        personBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
        personBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
        personBean.setDeptUuid(unitHkSetting.getDepartmentId());
        personBean.setPersonName(user.getUserName());
        personBean.setPersonNo(taUserHk.getHkPersonNo());
        personBean.setRemark(user.getLoginName());
        personBean.setCard(Long.valueOf(taUserHk.getHkCardNo()));
        personBean.setExpirationTime(expirationTime);

        PushPerson pushPerson = new PushPerson();
        pushPerson.setType(tpEquipmentTree.getFactory());
        pushPerson.setPerson(personBean);

        String result = ihkServer.pushPerson(JSONObject.toJSONString(pushPerson));
        ResponseBean responseBean = getResponseBean(result);
        return JSONObject.toJSONString(responseBean.getData());
    }

    @Override
    public String addFace(MultipartFile faceImg, TpUnitHkSetting unitHkSetting, TpEquipmentTree tpEquipmentTree,
                          TaUserHk taUserHk, TaUserVerify userVerify, TaUser user, List<String> visualList,
                          String doorUuids, String deviceUuids) {


        AddFace addFace = new AddFace();
        AddFace.FaceBean faceBean = new AddFace.FaceBean();

        // 人脸图片
        AddFace.FaceBean.PersonBean person = new AddFace.FaceBean.PersonBean();
        person.setAppkey(tpEquipmentTree.getAppkey());
        person.setSecret(tpEquipmentTree.getSecret());
        person.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
        person.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
        person.setPersonId(taUserHk.getHkUserId());
        person.setPersonNo(Long.valueOf(taUserHk.getHkPersonNo()));
        person.setPersonName(user.getUserName());
        person.setCardNo(taUserHk.getHkCardNo());

        faceBean.setPerson(person);


        if (CollectionUtils.isNotEmpty(visualList)) {
            // 门口机卡权限(可是对讲)
            AddFace.FaceBean.DoorPermissionsBean doorPermissionsBean = new AddFace.FaceBean.DoorPermissionsBean();
            doorPermissionsBean.setAppkey(tpEquipmentTree.getAppkey());
            doorPermissionsBean.setSecret(tpEquipmentTree.getSecret());
            doorPermissionsBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            doorPermissionsBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            doorPermissionsBean.setAuthName(user.getUserName()+userVerify.getId());
            doorPermissionsBean.setPersonIds(Arrays.asList(taUserHk.getHkUserId()));
            doorPermissionsBean.setLongNums(visualList);

            // 门口机人脸权限(可视对讲)
            AddFace.FaceBean.DoorFaceBean doorFaceBean = new AddFace.FaceBean.DoorFaceBean();
            doorFaceBean.setAppkey(tpEquipmentTree.getAppkey());
            doorFaceBean.setSecret(tpEquipmentTree.getSecret());
            doorFaceBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            doorFaceBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            doorFaceBean.setOpType(1);
            doorFaceBean.setLongNums(visualList);
            doorFaceBean.setPersonIds(Arrays.asList(taUserHk.getHkUserId()));

            faceBean.setDoorPermissions(doorPermissionsBean);
            faceBean.setDoorFace(doorFaceBean);
        }


        if (org.apache.commons.lang3.StringUtils.isNotBlank(doorUuids)) {
            // 门禁卡权限下发
            AddFace.FaceBean.EntranceGuardPermissionsBean entranceGuardPermissionsBean = new AddFace.FaceBean.EntranceGuardPermissionsBean();
            entranceGuardPermissionsBean.setAppkey(tpEquipmentTree.getAppkey());
            entranceGuardPermissionsBean.setSecret(tpEquipmentTree.getSecret());
            entranceGuardPermissionsBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            entranceGuardPermissionsBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            entranceGuardPermissionsBean.setPersonIds(String.valueOf(taUserHk.getHkUserId()));
            entranceGuardPermissionsBean.setDoorUuids(doorUuids.substring(0, doorUuids.lastIndexOf(",")));

            faceBean.setEntranceGuardPermissions(entranceGuardPermissionsBean);
        }

        if (org.apache.commons.lang3.StringUtils.isNotBlank(deviceUuids)) {

            // 门禁人脸权限下发
            AddFace.FaceBean.EntranceGuardFaceBean entranceGuardFaceBean = new AddFace.FaceBean.EntranceGuardFaceBean();
            entranceGuardFaceBean.setAppkey(tpEquipmentTree.getAppkey());
            entranceGuardFaceBean.setSecret(tpEquipmentTree.getSecret());
            entranceGuardFaceBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            entranceGuardFaceBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            entranceGuardFaceBean.setDeviceUuids(deviceUuids.substring(0, deviceUuids.lastIndexOf(",")));
            entranceGuardFaceBean.setType(1);
            entranceGuardFaceBean.setPersonIds(String.valueOf(taUserHk.getHkUserId()));

            faceBean.setEntranceGuardFace(entranceGuardFaceBean);
        }

        addFace.setType(tpEquipmentTree.getFactory());
        addFace.setFace(faceBean);
        // 添加人脸
        String result = ihkServer.addFace(faceImg, JSONObject.toJSONString(addFace));
        ResponseBean responseBean = getResponseBean(result);
        return JSONObject.toJSONString(responseBean.getData());
    }

    @Override
    public String updateFace(MultipartFile faceImg, TpUnitHkSetting unitHkSetting, TpEquipmentTree tpEquipmentTree, TaUserHk taUserHk, TaUserVerify userVerify, TaUser user, List<String> visualList, String doorUuids, String deviceUuids) {

        UpdateFace addFace = new UpdateFace();
        UpdateFace.FaceBean faceBean = new UpdateFace.FaceBean();

        // 人脸图片
        UpdateFace.FaceBean.PersonBean person = new UpdateFace.FaceBean.PersonBean();
        person.setAppkey(tpEquipmentTree.getAppkey());
        person.setSecret(tpEquipmentTree.getSecret());
        person.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
        person.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
        person.setPersonId(taUserHk.getHkUserId());
        person.setPersonNo(Long.valueOf(taUserHk.getHkCardNo()));
        person.setPersonName(user.getUserName());
        person.setCardNo(taUserHk.getHkCardNo());

        faceBean.setPerson(person);


        if (CollectionUtils.isNotEmpty(visualList)) {

            // 门口机卡权限(可是对讲)
            UpdateFace.FaceBean.DoorPermissionsBean doorPermissionsBean = new UpdateFace.FaceBean.DoorPermissionsBean();
            doorPermissionsBean.setAppkey(tpEquipmentTree.getAppkey());
            doorPermissionsBean.setSecret(tpEquipmentTree.getSecret());
            doorPermissionsBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            doorPermissionsBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            doorPermissionsBean.setAuthName(user.getUserName()+userVerify.getId());
            doorPermissionsBean.setPersonIds(Arrays.asList(taUserHk.getHkUserId()));
            doorPermissionsBean.setLongNums(visualList);

            faceBean.setDoorPermissions(doorPermissionsBean);


            // 门口机人脸权限(可视对讲)
            UpdateFace.FaceBean.DoorFaceBean doorFaceBean = new UpdateFace.FaceBean.DoorFaceBean();
            doorFaceBean.setAppkey(tpEquipmentTree.getAppkey());
            doorFaceBean.setSecret(tpEquipmentTree.getSecret());
            doorFaceBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            doorFaceBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            doorFaceBean.setOpType(1);
            doorFaceBean.setLongNums(visualList);
            doorFaceBean.setPersonIds(Arrays.asList(taUserHk.getHkUserId()));

            faceBean.setDoorFace(doorFaceBean);
        }

        if (org.apache.commons.lang3.StringUtils.isNotBlank(doorUuids)) {
            // 门禁卡权限下发
            UpdateFace.FaceBean.EntranceGuardPermissionsBean entranceGuardPermissionsBean = new UpdateFace.FaceBean.EntranceGuardPermissionsBean();
            entranceGuardPermissionsBean.setAppkey(tpEquipmentTree.getAppkey());
            entranceGuardPermissionsBean.setSecret(tpEquipmentTree.getSecret());
            entranceGuardPermissionsBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            entranceGuardPermissionsBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            entranceGuardPermissionsBean.setPersonIds(String.valueOf(taUserHk.getHkUserId()));
            entranceGuardPermissionsBean.setDoorUuids(doorUuids.substring(0, doorUuids.lastIndexOf(",")));

            faceBean.setEntranceGuardPermissions(entranceGuardPermissionsBean);
        }


        if (org.apache.commons.lang3.StringUtils.isNotBlank(deviceUuids)) {

            // 门禁人脸权限下发
            UpdateFace.FaceBean.EntranceGuardFaceBean entranceGuardFaceBean = new UpdateFace.FaceBean.EntranceGuardFaceBean();
            entranceGuardFaceBean.setAppkey(tpEquipmentTree.getAppkey());
            entranceGuardFaceBean.setSecret(tpEquipmentTree.getSecret());
            entranceGuardFaceBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            entranceGuardFaceBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            entranceGuardFaceBean.setDeviceUuids(deviceUuids.substring(0, deviceUuids.lastIndexOf(",")));
            entranceGuardFaceBean.setType(1);
            entranceGuardFaceBean.setPersonIds(String.valueOf(taUserHk.getHkUserId()));

            faceBean.setEntranceGuardFace(entranceGuardFaceBean);
        }

        addFace.setType(tpEquipmentTree.getFactory());
        addFace.setFace(faceBean);
        // 添加人脸
        String result = ihkServer.updateFace(faceImg, JSONObject.toJSONString(addFace));
        ResponseBean responseBean = getResponseBean(result);
        return JSONObject.toJSONString(responseBean.getData());
    }

    @Override
    public String deleteFace(TpUnitHkSetting unitHkSetting, TpEquipmentTree tpEquipmentTree, TaUserHk taUserHk, TaUserVerify userVerify, TaUser user, List<String> visualList, String doorUuids) {
        DeleteFace deleteFace = new DeleteFace();
        DeleteFace.FaceBean faceBean = new DeleteFace.FaceBean();

        if (CollectionUtils.isNotEmpty(visualList)) {
            // 门口机卡权限(可是对讲)
            DeleteFace.FaceBean.DoorPermissionsBean doorPermissionsBean = new DeleteFace.FaceBean.DoorPermissionsBean();
            doorPermissionsBean.setAppkey(tpEquipmentTree.getAppkey());
            doorPermissionsBean.setSecret(tpEquipmentTree.getSecret());
            doorPermissionsBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            doorPermissionsBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            doorPermissionsBean.setPersonIds(Arrays.asList(taUserHk.getHkUserId()));
            doorPermissionsBean.setLongNums(visualList);
            // 表示删除
            doorPermissionsBean.setOperateType(2);

            faceBean.setDoorPermissions(doorPermissionsBean);

            /**
             * 删除了卡权限，人脸权限也应该没有了
             */

            // 门口机人脸权限(可视对讲)
//            DeleteFace.FaceBean.DoorFaceBean doorFaceBean = new DeleteFace.FaceBean.DoorFaceBean();
//            doorFaceBean.setAppkey(tpEquipmentTree.getAppkey());
//            doorFaceBean.setSecret(tpEquipmentTree.getSecret());
//            doorFaceBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
//            doorFaceBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
//            doorFaceBean.setOpType(2);
//            doorFaceBean.setLongNums(visualList);
//            doorFaceBean.setPersonIds(Arrays.asList(taUserHk.getHkUserId()));
//
//
//            faceBean.setDoorFace(doorFaceBean);
        }


        if (org.apache.commons.lang3.StringUtils.isNotBlank(doorUuids)) {
            // 门禁卡权限下发
            DeleteFace.FaceBean.EntranceGuardPermissionsBean entranceGuardPermissionsBean = new DeleteFace.FaceBean.EntranceGuardPermissionsBean();
            entranceGuardPermissionsBean.setAppkey(tpEquipmentTree.getAppkey());
            entranceGuardPermissionsBean.setSecret(tpEquipmentTree.getSecret());
            entranceGuardPermissionsBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            entranceGuardPermissionsBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            entranceGuardPermissionsBean.setPersonIds(String.valueOf(taUserHk.getHkUserId()));

            faceBean.setEntranceGuardPermissions(entranceGuardPermissionsBean);
        }

        deleteFace.setType(tpEquipmentTree.getFactory());
        deleteFace.setFace(faceBean);
        // 删除人脸
        String result = ihkServer.deleteFace(JSONObject.toJSONString(deleteFace));
        ResponseBean responseBean = getResponseBean(result);
        return JSONObject.toJSONString(responseBean.getData());
    }

    @Override
    public String temporaryRegister(String visitorName, String phoneNo, Integer personNum, Long startTime, Long endTime, Integer personId, TpEquipmentTree tpEquipmentTree) {

        TemporaryRegister temporaryRegister = new TemporaryRegister();
        temporaryRegister.setType(tpEquipmentTree.getFactory());
        TemporaryRegister.TemporaryRegisterBean temporaryRegisterBean = new TemporaryRegister.TemporaryRegisterBean();
        temporaryRegisterBean.setVisitorName(visitorName);
        temporaryRegisterBean.setPhoneNo(phoneNo);
        temporaryRegisterBean.setPersonNum(personNum);
        temporaryRegisterBean.setStartTime(startTime);
        temporaryRegisterBean.setEndTime(endTime);
        temporaryRegisterBean.setPersonId(personId);
        temporaryRegisterBean.setAppkey(tpEquipmentTree.getAppkey());
        temporaryRegisterBean.setSecret(tpEquipmentTree.getSecret());
        temporaryRegisterBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());

        temporaryRegister.setTemporaryRegister(temporaryRegisterBean);


        String result = ihkServer.temporaryRegister(JSONObject.toJSONString(temporaryRegister));
        ResponseBean responseBean = getResponseBean(result);
        return JSONObject.toJSONString(responseBean.getData());
    }

    @Override
    public String syncControl(String longNums, String factory,TpEquipmentTree tpEquipmentTree, String device) {
        SyncControl syncControl = new SyncControl();
        SyncControl.SyncBean syncBean = new SyncControl.SyncBean();
        syncBean.setLongNums(longNums);
        // KSDJ  可视对讲  (从数据库查询)
        syncBean.setEquipmentType(device);
        syncBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
        syncBean.setSecret(tpEquipmentTree.getSecret());
        syncBean.setAppkey(tpEquipmentTree.getAppkey());
        syncBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());

        syncControl.setSync(syncBean);
        syncControl.setType(factory);

        String result = ihkServer.syncControl(JSONObject.toJSONString(syncControl));
        ResponseBean responseBean = getResponseBean(result);
        return JSONObject.toJSONString(responseBean.getData());
    }


    @Override
    public String deletePerson(TaUserHk userHk, TpEquipmentTree tpEquipmentTree) {
        DeletePerson deletePerson = new DeletePerson();
        DeletePerson.PersonBean personBean = new DeletePerson.PersonBean();
        personBean.setAppkey(tpEquipmentTree.getAppkey());
        personBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
        personBean.setSecret(tpEquipmentTree.getSecret());
        personBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
        personBean.setPersonIds(String.valueOf(userHk.getHkUserId()));

        if (StringUtils.isNotBlank(userHk.getHkCardNo())) {
            DeletePerson.PersonBean.CardNoBean cardNoBean = new DeletePerson.PersonBean.CardNoBean();
            cardNoBean.setAppkey(tpEquipmentTree.getAppkey());
            cardNoBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
            cardNoBean.setSecret(tpEquipmentTree.getSecret());
            cardNoBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());
            cardNoBean.setPersonId(userHk.getHkUserId());
            cardNoBean.setCardNo(userHk.getHkCardNo());

            personBean.setCardNo(cardNoBean);
        }

        deletePerson.setPerson(personBean);
        deletePerson.setType(tpEquipmentTree.getFactory());

        String result = ihkServer.deletePerson(JSONObject.toJSONString(deletePerson));
        ResponseBean responseBean = getResponseBean(result);
        return JSONObject.toJSONString(responseBean.getData());
    }

    @Override
    public String acsSyncControl(String doorUuid, String factory, TpEquipmentTree tpEquipmentTree, Integer command, String device) {

        AcsSyncControl acsSyncControl = new AcsSyncControl();
        AcsSyncControl.SyncBean syncBean = new AcsSyncControl.SyncBean();
        // MJ  门禁  (从数据库查询)
        syncBean.setEquipmentType(device);
        syncBean.setDoorUuid(doorUuid);
        syncBean.setCommand(command);
        syncBean.setOpenapi_ip_port_http(tpEquipmentTree.getHttpServer());
        syncBean.setSecret(tpEquipmentTree.getSecret());
        syncBean.setAppkey(tpEquipmentTree.getAppkey());
        syncBean.setOpUserUuid(tpEquipmentTree.getOpUserUuid());

        acsSyncControl.setSync(syncBean);
        acsSyncControl.setType(factory);

        String result = ihkServer.syncControl(JSONObject.toJSONString(acsSyncControl));
        ResponseBean responseBean = getResponseBean(result);
        return JSONObject.toJSONString(responseBean.getData());
    }
}
