package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.huiju.common.messagePush;
import com.community.huiju.dao.*;
import com.community.huiju.model.*;
import com.community.huiju.service.MessageServiceI;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.hibernate.validator.internal.util.logging.Log;
import org.springframework.util.StringUtils;
import org.springframework.web.client.RestTemplate;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author FXF
 * @date 2018-10-22
 */
@Service("messageService")
@Slf4j
public class MessageServiceImpl implements MessageServiceI {

	@Autowired
	private TpMessageMapper tpMessageMapper;

	@Autowired
	private TpBillMapper tpBillMapper;

	@Autowired
	private TpTicketMapper tpTicketMapper;

	@Autowired
	private TpTransactionMapper tpTransactionMapper;

	@Autowired
	private TdModelMapper tdModelMapper;

	@Autowired
	private  TaUserVerifyMapper taUserVerifyMapper;

	@Autowired
	private TaUserMapper taUserMapper;

	@Autowired
	private  TpAnnouncementMapper tpAnnouncementMapper;

	@Autowired
	private  TpActivityMapper tpActivityMapper;

	@Autowired
	private  TpShopMapper tpShopMapper;


	/**
	 * 获取消息数量
	 * @param communityId
	 * @return
	 */
	@Override
	public Map<String, Object> getMessageTotal(Integer communityId, Integer verifyId) {
		return tpMessageMapper.getMessageTotal(verifyId,communityId);
	}

	/**
	 * 分页获取消息或待办
	 * @param communityId
	 * @param pageNum
	 * @param pageSize
	 * @param modelType
	 * @return
	 */
	@Override
	public Map<String,Object> getMessages(Integer communityId, Integer pageNum, Integer pageSize,Integer modelType, Integer verifyId) {
		//使用分页插件
		Page page = PageHelper.startPage(pageNum, pageSize);
		// 获取数据
		List<TpMessage> messageList = tpMessageMapper.getMessages(verifyId,communityId, modelType);
		// 查找标题
		for (TpMessage tpMessage:messageList){
			// 工单
			if (Constant.MESSAGE_UUID_TYPE_TICKET.equals(tpMessage.getMessageUuidType())) {
				TpTicket tpTicket = tpTicketMapper.selectByPrimaryKey(tpMessage.getMessageUuid());
				tpMessage.setContent(tpTicket.getTicketTitle());
			}
			// 话题
			if (Constant.MESSAGE_UUID_TYPE_TRANSACTION.equals(tpMessage.getMessageUuidType())){
				TpTransaction tpTransaction = tpTransactionMapper.selectByPrimaryKey(tpMessage.getMessageUuid(),tpMessage.getCommunityId());
				tpMessage.setContent(tpTransaction.getTransactionTitle());
			}
			// 公告
			if (Constant.MESSAGE_UUID_TYPE_ANNOUNCEMENT.equals(tpMessage.getMessageUuidType())){
				TpAnnouncement tpAnnouncement = tpAnnouncementMapper.selectByPrimaryKey(tpMessage.getMessageUuid(),tpMessage.getCommunityId());
				tpMessage.setContent(tpAnnouncement.getAnnouncementTitle());
			}
			// 活动
			if (Constant.MESSAGE_UUID_TYPE_ACTIVITY.equals(tpMessage.getMessageUuidType())){
				TpActivity tpActivity = tpActivityMapper.selectById(tpMessage.getMessageUuid());
				tpMessage.setContent(tpActivity.getActivityTitle());
			}
			// 收费组名称
			if (Constant.MESSAGE_UUID_TYPE_BILL.equals(tpMessage.getMessageUuidType())){
			    TpBill tpBill = tpBillMapper.selectByPrimaryKey(tpMessage.getMessageUuid());
				tpMessage.setContent(tpBill.getBillName());
			}
			// 商铺
			if (Constant.MESSAGE_UUID_TYPE_SHOP.equals(tpMessage.getMessageUuidType())){
				TpShop tpShop = tpShopMapper.selectByPrimaryKey(tpMessage.getMessageUuid());
				tpMessage.setContent(tpShop.getShopName());
			}

			//活动被作废
			if (Constant.MESSAGE_UUID_TYPE_ACTIVITY.equals(tpMessage.getMessageUuidType())){
				TpMessage message = tpMessageMapper.selectByPrimaryKey(tpMessage.getId());
				if(Constant.ACTIVITY_CANCELLED.equals(message.getMessageType())) {
					tpMessage.setMessageDetailUrl(null);
					tpMessage.setContent(null);
				}
			}
			//话题被作废
			if(Constant.MESSAGE_UUID_TYPE_TRANSACTION.equals(tpMessage.getMessageUuidType())){
				TpMessage message = tpMessageMapper.selectByPrimaryKey(tpMessage.getId());
				if(Constant.THREAD_CANCELLED.equals(message.getMessageType())){
					tpMessage.setMessageDetailUrl(null);
					tpMessage.setContent(null);
				}
			}
		}
		Map<String,Object> map = new HashMap<>();
		map.put("list",messageList);
		map.put("total",page.getTotal());
		return map;
	}

	/**
	 * 消息全部已读
	 */
	@Override
	public void updateMessageReadStatus(Integer communityId, Integer userId) {
		tpMessageMapper.updateReadStatus(communityId, userId);
	}

	@Override
	public ResponseBean updateMessageByIdReadStatus(UserElement userElement, Integer messageId) {
		ResponseBean responseBean = new ResponseBean();

		TpMessage tpMessage = tpMessageMapper.selectByPrimaryKey(messageId);
		if (null == tpMessage) {
			responseBean.addError("消息不存在!");
			return responseBean;
		}
		tpMessage.setReadStatus("1");
		tpMessage.setUpdateDate(new Date());
		tpMessage.setUpdateUser(userElement.getUserVerifyId());
		int row = tpMessageMapper.updateByPrimaryKeySelective(tpMessage);
		if (row > 0) {
			responseBean.addSuccess("操作成功!");
			return responseBean;
		}
		responseBean.addError("操作失败!");
		return responseBean;
	}

	/**
	 * 举报话题时推消息
	 * communityId：小区
	 * userVerify：房产
	 * reportCount:举报原因
	 * createUserId:创建人
	 * transactionId：帖子ID
	 * @param paramsMap
	 */
	@Override
	public void threadReport(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.THREAD_REPORT);
		tpMessage.setAdviceType(Constant.FORUM_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("userVerify").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_APP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.THREAD_REPORT);
		String content = tdModel.getModelContent().replace("{reportCount}",paramsMap.get("reportCount").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("transactionId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TRANSACTION);
		tpMessageMapper.insert(tpMessage);
	}

	/**话题被作废后推消息
	 * communityId:小区ID
	 * taUserVerifyId：房产ID
	 * transactionTitle：话题标题
	 * createUserId：创建人
	 * transactionId：帖子ID
	 * @param paramsMap
	 */
	@Override
	public void threadCancelled(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.THREAD_CANCELLED);
		tpMessage.setAdviceType(Constant.FORUM_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_APP);
		tpMessage.setSource(Constant.SOURCE_PROP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.THREAD_CANCELLED);
		String content = tdModel.getModelContent().replace("{transactionTitle}",paramsMap.get("transactionTitle").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("transactionId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TRANSACTION);
		tpMessageMapper.insert(tpMessage);
	}

	/**
	 * 工单被拒绝后，推消息
	 * communityId：小区ID
	 * taUserVerifyId：房产ID
	 * refuseCount：拒绝内容
	 * ticketId：工单ID
	 * createUserId：创建人
	 *
	 * @param paramsMap
	 */
	@Override
	public void ticketRejected(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.TICKET_REJECTED);
		tpMessage.setAdviceType(Constant.TICKET_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_APP);
		tpMessage.setSource(Constant.SOURCE_PROP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.TICKET_REJECTED);
		String content = tdModel.getModelContent().replace("{refuseCount}",paramsMap.get("refuseCount").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
		tpMessageMapper.insert(tpMessage);
	}

	/**
	 * 工单被受理后，推消息
	 * communityId：小区ID
	 * taUserVerifyId：房产ID
	 * ticketId：工单ID
	 *
	 * @param paramsMap
	 */
	@Override
	public void ticketDistributed(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.TICKET_DISTRIBUTED);
		tpMessage.setAdviceType(Constant.TICKET_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("userID").toString()));
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.TICKET_DISTRIBUTED);
		if (null != paramsMap.get("state").toString()&&paramsMap.get("state").toString().equals("prop")){
			// 此处为了推物业端消息通知
			tpMessage.setMessageContent("工单“" + paramsMap.get("ticketTitle").toString() + "”已被分配给您，点击查看并处理");
			tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		}else {
			tpMessage.setUuidType(Constant.UUID_TYPE_APP);
			String content = tdModel.getModelContent();
			tpMessage.setMessageContent(content);
		}
		tpMessage.setSource(Constant.SOURCE_PROP);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
		tpMessageMapper.insert(tpMessage);
	}

	/**
	 * 工单处理结果推消息
	 * communityId：小区ID
	 * taUserVerifyId：房产ID
	 * ticketResult：推送结果
	 * ticketId：工单ID
	 * createUserId：创建人
	 * @param paramsMap
	 */
	@Override
	public void ticketSubmitResult(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.TICKET_SUBMIT_RESULT);
		tpMessage.setAdviceType(Constant.TICKET_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_APP);
		tpMessage.setSource(Constant.SOURCE_PROP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.TICKET_SUBMIT_RESULT );
		String content = tdModel.getModelContent().replace("{ticketResult}",paramsMap.get("ticketResult").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
		tpMessageMapper.insert(tpMessage);
	}


	/**
	 * 回复工单（个人管理中心）
	 * communityId:小区ID
	 *taUserVerifyId:房产
	 * createUserId：创建人
	 * ticketId:工单ID
	 * uuidType:接收类型app/porp
	 *source:来源app/porp
	 * @param paramsMap
	 */
	@Override
	public void ticketReply(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.TICKET_REPLY);
		tpMessage.setAdviceType(Constant.TICKET_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("uuId").toString()));
		tpMessage.setUuidType(paramsMap.get("uuidType").toString());
		tpMessage.setSource(paramsMap.get("source").toString());
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.TICKET_REPLY );
		String content = tdModel.getModelContent().replace("{replyCount}",paramsMap.get("replyCount").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
		tpMessageMapper.insert(tpMessage);
	}

	/**
	 * app回复物业
	 * communityId:小区ID
	 *taUserVerifyId:房产
	 * createUserId：创建人
	 * ticketId:工单ID
	 * uuidType:接收类型app/porp
	 *source:来源app/porp
	 * @param paramsMap
	 */
	public void ticketReplyProp(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.TICKET_REPLY_PROP);
		tpMessage.setAdviceType(Constant.TICKET_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("uuId").toString()));
		tpMessage.setUuidType(paramsMap.get("uuidType").toString());
		tpMessage.setSource(paramsMap.get("source").toString());
		//获取消息内容
//		TdModel tdModel = tdModelMapper.selectModelContent(Constant.TICKET_REPLY );
//		String content = tdModel.getModelContent().replace("{replyCount}",paramsMap.get("replyCount").toString());
		tpMessage.setMessageContent(paramsMap.get("replyCount").toString());
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
		tpMessageMapper.insert(tpMessage);
	}

	/**app评价回复物业
	 * 回复工单（个人管理中心）
	 * communityId:小区ID
	 *taUserVerifyId:房产
	 * createUserId：创建人
	 * ticketId:工单ID
	 * uuidType:接收类型app/porp
	 *source:来源app/porp
	 * @param paramsMap
	 */
	public void ticketEvaluateProp(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.TICKET_EVALUATE_PROP);
		tpMessage.setAdviceType(Constant.TICKET_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("uuId").toString()));
		tpMessage.setUuidType(paramsMap.get("uuidType").toString());
		tpMessage.setSource(paramsMap.get("source").toString());
		//获取消息内容
//		TdModel tdModel = tdModelMapper.selectModelContent(Constant.TICKET_REPLY );
//		String content = tdModel.getModelContent().replace("{replyCount}",paramsMap.get("replyCount").toString());
		tpMessage.setMessageContent(paramsMap.get("replyCount").toString());
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
		tpMessageMapper.insert(tpMessage);
	}

	@Override
	public ResponseBean messageReadStatus(UserElement userElement, Integer messageId) {
		ResponseBean responseBean = new ResponseBean<>();
		TpMessage tpMessage = new TpMessage();
		tpMessage.setId(messageId);
		tpMessage.setReadStatus("1");
		tpMessage.setUpdateDate(new Date());
		tpMessage.setUpdateUser(userElement.getUserVerifyId());
		tpMessageMapper.updateByPrimaryKeySelective(tpMessage);
		responseBean.addSuccess("成功");
		return responseBean;
	}


	/**
	 * 家属或租客提交审核信息
	 * communityId：小区ID
	 * userVerify：房产ID
	 * name：审核姓名
	 * roleName：审核角色
	 * createUserId：创建人
	 * @param paramsMap
	 */
	@Override
	public void customerSubmitVerify(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.CUSTOMER_SUBMIT_VERIFY);
		tpMessage.setAdviceType(Constant.SYS_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("userVerify").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_APP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.CUSTOMER_SUBMIT_VERIFY);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString()).replace("{roleName}",paramsMap.get("roleName").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("userVerify").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_AUDIT);
		tpMessageMapper.insert(tpMessage);
	}


	/**
	 * 根据消息ID 查询详情数据
	 *
	 * @param communityId
	 * @param messageId
	 * @return
	 */
	@Override
	public ResponseBean getMessageById(Integer communityId, Integer messageId) {
		ResponseBean responseBean = new ResponseBean();
		TpMessage tpMessage = tpMessageMapper.selectByPrimaryKey(messageId);
		if (null != tpMessage){
			// 设置当前工单类型
			if (Constant.MESSAGE_UUID_TYPE_TICKET.equals(tpMessage.getMessageUuidType())){
				TpTicket tpTicket= tpTicketMapper.selectByPrimaryKey(tpMessage.getMessageUuid());
				tpMessage.setTicketType(tpTicket.getType());
			}
			// 当前发帖人是否存在(app发帖)
			if (Constant.MESSAGE_UUID_TYPE_TRANSACTION.equals(tpMessage.getMessageUuidType())){
				TpTransaction tpTransaction = tpTransactionMapper.selectByPrimaryKey(tpMessage.getMessageUuid(),tpMessage.getCommunityId());
				if ("app".equals(tpTransaction.getUuidType())){
					TaUserVerify taUserVerify = taUserVerifyMapper.selectByPrimaryKey(tpTransaction.getUuid());
					if (null == taUserVerify){
						responseBean.addError("此贴已丢失，无法查看");
						return  responseBean;
					}
				}
			}
			responseBean.addSuccess(tpMessage);
			return responseBean;
		}
		responseBean.addError("不存在的ID");
		return responseBean;
	}

	/**
	 * 话题被回复
	 * @param paramsMap
	 *         communityId 小区ID
	 *         taUserVerifyId  审核ID
	 *         createUserId 创建人ID
	 *         propName 物业姓名
	 *         content 回复内容
	 *         transactionId 话题ID
	 *         source：来源app/物业
	 */
	@Override
	public void threadReply(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.THREAD_REPLY);
		tpMessage.setAdviceType(Constant.FORUM_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("userID").toString()));
		tpMessage.setUuidType(paramsMap.get("uuidType").toString());
		tpMessage.setSource(paramsMap.get("source").toString());
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.THREAD_REPLY);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("propName").toString()).replace("{content}",paramsMap.get("content").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("transactionId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TRANSACTION);
		tpMessageMapper.insert(tpMessage);

	}

	/**
	 * 房产关联审核通过
	 * @param paramsMap
	 *         communityId 小区ID
	 *         taUserVerifyId  审核ID
	 *         createUserId 创建人ID
	 */
	@Override
	public void estateRelateVerifyPassed(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.ESTATE_RELATE_VERIFY_PASSED);
		tpMessage.setAdviceType(Constant.SMS_NOTIFICATION);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_APP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.ESTATE_RELATE_VERIFY_PASSED);

		tpMessage.setMessageContent(tdModel.getModelContent());
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_READ);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		//插入消息表
		tpMessageMapper.insert(tpMessage);
		//发送短信给客户，先查询出手机号码
		TaUser taUser = getUserPhoneByVerifyId(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
		sendSMS(taUser.getLoginName(),Constant.ESTATE_RELATE_VERIFY_PASSED_SMS);

	}

	/**
	 * 根据审核id获取用户信息
	 * @param userVerifyId
	 * @return
	 */
	private TaUser getUserPhoneByVerifyId(Integer userVerifyId) {
		TaUserVerify taUserVerify = taUserVerifyMapper.selectByPrimaryKey(userVerifyId);
		return taUserMapper.selectByPrimaryKey(taUserVerify.getUserId());
	}

	/**
	 * 房产关联审核不通过
	 * @param paramsMap
	 *         communityId 小区ID
	 *         taUserVerifyId  审核ID
	 *         createUserId 创建人ID
	 */
	@Override
	public void estateRelateVerifyRejected(Map<String, Object> paramsMap) {
		if (null == paramsMap) {
			return;
		}
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.ESTATE_RELATE_VERIFY_REJECTED);
		tpMessage.setAdviceType(Constant.SMS_NOTIFICATION);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_APP);
		tpMessage.setSource(Constant.SOURCE_APP);
		// 获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.ESTATE_RELATE_VERIFY_REJECTED);
		tpMessage.setMessageContent(tdModel.getModelContent());
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_READ);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		//维护消息
		tpMessageMapper.insert(tpMessage);
		//发送短信给客户，先查询出手机号码
		TaUser taUser = getUserPhoneByVerifyId(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
		sendSMS(taUser.getLoginName(), Constant.ESTATE_RELATE_VERIFY_REJECTED_SMS);
	}

	/**消息15条
	 *communityId:小区
	 * taUserVerifyId:房产ID
	 * createUserId:创建人
	 * @param paramsMap
	 */
	@Override
	public void systemMessage(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		// 15条消息数据
		String[] messageArr= new messagePush().messagePushAll( );
		for (String count : messageArr) {
			//保存消息表
			TpMessage tpMessage = new TpMessage();
			tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
			tpMessage.setMessageType(Constant.SYSTEM_MESSAGE_TYPE);
			tpMessage.setAdviceType(Constant.SYS_NEWS);
			tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
			tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
			tpMessage.setUuidType(Constant.UUID_TYPE_APP);
			tpMessage.setSource(Constant.SOURCE_APP);
			tpMessage.setMessageContent(count);
			tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
			tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
			tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
			tpMessage.setCreateDate(new Date());
			//插入消息表
			tpMessageMapper.insert(tpMessage);
		 }
		}

	/**业主/家属/租客提交审核时推物业端
	 *communityId:小区
	 *tpUserId:物业端管理员ID
	 * createUserId：创建人
	 * name:审核人名字
	 *userVerifyId:审核房产ID
	 * @param paramsMap
	 */
	@Override
	public void customerSubmitPropVerify(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.CUSTOMER_SUBMIT_PROP_VERIFY);
		tpMessage.setAdviceType(Constant.AUDIT_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.CUSTOMER_SUBMIT_PROP_VERIFY);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("userVerifyId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_AUDIT);
		tpMessageMapper.insert(tpMessage);
	}

	/**添加话题推送物业端
	 * communityId：小区
	 * tpUserId：管理员ID
	 * createUserId：创建人ID
	 * transactionID:帖子ID
	 * name:业主名字
	 * title：帖子标题
	 * @param paramsMap
	 */
	@Override
	public void threadAddTransaction(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.THREAD_ADD_TRANSACTION);
		tpMessage.setAdviceType(Constant.FORUM_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.THREAD_ADD_TRANSACTION);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString()).replace("{title}",paramsMap.get("title").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("transactionID").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TRANSACTION);
		tpMessageMapper.insert(tpMessage);
	}

	/**
	 * 话题被举报推物业端
	 * communityId:小区ID
	 * tpUserId:管理员ID
	 * name：举报人的名称
	 * title:话题标题
	 * createUserId:创建人ID
	 * transactionId:话题ID
	 * @param paramsMap
	 */
	@Override
	public void threadReportProp(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.THREAD_REPORT_RROP);
		tpMessage.setAdviceType(Constant.FORUM_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.THREAD_REPORT_RROP);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString()).replace("{title}",paramsMap.get("title").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("transactionId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TRANSACTION);
		tpMessageMapper.insert(tpMessage);
	}

	/**话题被修改时推送物业端消息
	 * communityId：小区
	 * tpUserId：管理元ID
	 * name：修改话题的业主
	 * title：修改的标题
	 * createUserId：创建人ID
	 * transactionID：话题ID
	 * @param paramsMap
	 */
	@Override
	public void threadUpdateTransaction(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.THREAD_UPDATE_TRANSACTION);
		tpMessage.setAdviceType(Constant.FORUM_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.THREAD_UPDATE_TRANSACTION);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString()).replace("{title}",paramsMap.get("title").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("transactionID").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TRANSACTION);
		tpMessageMapper.insert(tpMessage);
	}

	/**添加工单时推送物业端
	 * communityId：小区
	 * tpUserId:管理员ID
	 *title:工单标题
	 * name：业主姓名
	 * createUserId创建人ID
	 * ticketId：工单ID
	 * @param paramsMap
	 */
	@Override
	public void ticketAdd(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.TICKET_ADD);
		tpMessage.setAdviceType(Constant.TICKET_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.TICKET_ADD);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString()).replace("{title}",paramsMap.get("title").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
		tpMessageMapper.insert(tpMessage);
	}

	/**
	 * 工单终止推物业
	 * communityId：小区ID
	 * tpUserId：管理员ID
	 * name：业主名称
	 * title：标题
	 * createUserId：创建人姓名
	 * ticketId：工单ID
	 * @param paramsMap
	 */
	@Override
	public void ticketTermination(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.TICKET_TERMINATION);
		tpMessage.setAdviceType(Constant.TICKET_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.TICKET_TERMINATION);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString()).replace("{title}",paramsMap.get("title").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
		tpMessageMapper.insert(tpMessage);
	}

	/**
	 * 工单修改时推物业
	 * communityId：小区ID
	 * tpUserId：管理员ID
	 * name：业主名称
	 * title：标题
	 * createUserId：创建人姓名
	 * ticketId：工单ID
	 * @param paramsMap
	 */
	@Override
	public void ticketUpdate(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.TICKET_UPDATE);
		tpMessage.setAdviceType(Constant.TICKET_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.TICKET_UPDATE);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString()).replace("{title}",paramsMap.get("title").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
		tpMessageMapper.insert(tpMessage);
	}

	/**缴费单成功时推物业端消息
	 *communityId：小区ID
	 * tpUserId：管理员ID
	 * name：缴费人名称
	 * createUserId：创建人ID
	 * billInvoiceId：订单ID
	 * @param paramsMap
	 */
	@Override
	public void payTypeSucceed(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.PAY_TYPE_SUCCEED);
		tpMessage.setAdviceType(Constant.BILL_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.PAY_TYPE_SUCCEED);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("billInvoiceId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_BILL);
		tpMessageMapper.insert(tpMessage);
	}

	/**月租车缴费成功时推送消息
	 * communityId：小区ID
	 * tpUserId：物业管理员ID
	 *name:缴费人名字
	 * number：车牌号
	 *createUserId:创建人名称
	 *licenseOrderId:月租车ID
	 * number：车牌号
	 * @param paramsMap
	 */
	@Override
	public void payMonthBillSucceed(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.PAY_MONTH_Bill_SUCCEED);
		tpMessage.setAdviceType(Constant.BILL_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.PAY_MONTH_Bill_SUCCEED);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString()).replace("{number}",paramsMap.get("number").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("licenseOrderId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_BILL);
		tpMessageMapper.insert(tpMessage);
	}

	/**商铺评价时推送消息
	 * communityId：小区id
	 * tpUserId：用户管理员ID
	 * name：评价人名称
	 * shopName:商铺名称
	 * createUserId：创建人名称
	 * shopID：商铺ID
	 * @param paramsMap
	 */
	@Override
	public void shopReviewPropReply(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}
		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.SHOP_REVIEW_PROP_REPLY);
		tpMessage.setAdviceType(Constant.OTHER_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.SHOP_REVIEW_PROP_REPLY);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString()).replace("{shopName}",paramsMap.get("shopName").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("shopID").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_SHOP);
		tpMessageMapper.insert(tpMessage);
	}


	/**家/租/户报名活动时推消息
	 * communityId：小区
	 * tpUserId：管理员ID
	 * createUserId：创建人ID
	 * activitySignID:活动报名ID
	 * name：报名人姓名
	 * @param paramsMap
	 */
	@Override
	public void estateServiceActivitySignSuccess(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		TpMessage tpMessage = new TpMessage();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.ESTATE_SERVICE_ACTIVITY_SIGN_SUCCESS);
		tpMessage.setAdviceType(Constant.FORUM_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("tpUserId").toString()));
		tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
		tpMessage.setSource(Constant.SOURCE_APP);
		//获取消息内容
		TdModel tdModel = tdModelMapper.selectModelContent(Constant.ESTATE_SERVICE_ACTIVITY_SIGN_SUCCESS);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("name").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(new Date());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("activitySignID").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_ACTIVITY);
		tpMessageMapper.insert(tpMessage);
	}

	/**
	 * 发送短信
	 * @param phone
	 * @param smsCode
	 */
	private void sendSMS(String phone, String smsCode) {
		RestTemplate restTemplate = new RestTemplate();
		HttpHeaders headers = new HttpHeaders();
		MediaType type = MediaType.parseMediaType("application/json; charset=UTF-8");
		headers.setContentType(type);
		headers.add("Accept", MediaType.APPLICATION_JSON.toString());
		JSONObject jsonObject = new JSONObject();
		jsonObject.put("code",smsCode);
		jsonObject.put("tel",phone);
		HttpEntity<String> formEntity = new HttpEntity<String>(jsonObject.toJSONString(), headers);
		ResponseEntity<String> stringResponseEntity = restTemplate.postForEntity(Constant.REQUEST_URL, formEntity, String.class);
		log.info("发送短信结果-> {}",stringResponseEntity.getBody());
	}
}
