package com.community.huiju.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.common.base.BaseController;
import com.community.huiju.model.TdModel;
import com.community.huiju.service.ITdModelService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 模板表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-08-02
 */
@RestController
@RequestMapping("/")
public class TdModelController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdModelController.class);

    @Autowired
    public ITdModelService iTdModelService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/tdModel",method= RequestMethod.GET)
    public ResponseBean tdModelList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                    @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TdModel> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TdModel> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TdModel> result = iTdModelService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdModelList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param tdModel 实体对象
     * @return
     */
    @RequestMapping(value="/tdModel",method= RequestMethod.POST)
    public ResponseBean tdModelAdd(@RequestBody TdModel tdModel){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdModelService.save(tdModel)){
                responseBean.addSuccess(tdModel);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdModelAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/tdModel/{id}", method= RequestMethod.DELETE)
    public ResponseBean tdModelDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTdModelService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdModelDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdModel 实体对象
     * @return
     */
    @RequestMapping(value="/tdModel/{id}",method= RequestMethod.PUT)
    public ResponseBean tdModelUpdate(@PathVariable Integer id,
                                        @RequestBody TdModel tdModel){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdModelService.updateById(tdModel)){
                responseBean.addSuccess(tdModel);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdModelUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tdModel/{id}",method= RequestMethod.GET)
    public ResponseBean tdModelGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTdModelService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdModelDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
