package com.community.huiju.service.impl;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.common.base.messagePush;
import com.community.huiju.dao.*;
import com.community.huiju.model.*;
import com.community.huiju.service.IMessageService;
import lombok.extern.slf4j.Slf4j;
import org.hibernate.validator.internal.util.logging.Log;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import java.time.LocalDateTime;
import java.util.*;

/**
 * <p>
 * 物业端消息表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-03-05
 */
@Service
@Slf4j
public class MessageServiceImpl extends ServiceImpl<MessageMapper, Message> implements IMessageService {
    @Autowired
    private MessageMapper messageMapper;
    
    @Autowired
    private TdModelMapper tdModelMapper;
    
    @Autowired
    private TaUserVerifyMapper taUserVerifyMapper;
    
    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private TpActivitySignUpMapper tpActivitySignUpMapper;
    
    @Override
    public ResponseBean messageLiset(String parameter, Integer communityId,Integer user) {
        ResponseBean response= new  ResponseBean();
        JSONObject  object = JSONObject.parseObject(parameter);
        //待办消息类型(-1:论坛，-2:工单，-3:缴费)
        String  messageType = object.getString("messageType");
        //0:无效，1:有效
        String  status = object.getString("status");
        Date createDate = object.getDate("createDate");

        String  messageContent = object.getString("messageContent");
        Integer pageNum = object.getInteger("pageNum");
        Integer pageSize = object.getInteger("pageSize");

        Page<Message> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
        IPage<Message> pageInfo = messageMapper.messageLiset(page,messageType,status,createDate,messageContent,user);
        List<Message> ticketList = pageInfo.getRecords();
        HashMap map=new HashMap<>();
        map.put("list",ticketList);
        map.put("total", pageInfo.getTotal());
        map.put("pageNum", pageInfo.getCurrent());
        map.put("pageSize", pageInfo.getSize());
        response.addSuccess(map);
        return response;
    }

    @Override
    public ResponseBean myMessageList(String parameter, Integer communityId, Integer user) {
        ResponseBean response= new  ResponseBean();
        JSONObject  object = JSONObject.parseObject(parameter);
        //待办消息类型(-1:论坛，-2:工单，-3:缴费)
        String  messageType = object.getString("messageType");
        //0:无效，1:有效
        String  readStatus = object.getString("readStatus");
        Date createDate = object.getDate("createDate");

        String  messageContent = object.getString("messageContent");
        Integer pageNum = object.getInteger("pageNum");
        Integer pageSize = object.getInteger("pageSize");

        Page<Message> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
        IPage<Message> pageInfo = messageMapper.myMessageList(page,messageType,readStatus,createDate,messageContent,user);
        List<Message> ticketList = pageInfo.getRecords();
        HashMap map=new HashMap<>();
        map.put("list",ticketList);
        map.put("total", pageInfo.getTotal());
        map.put("pageNum", pageInfo.getCurrent());
        map.put("pageSize", pageInfo.getSize());
        response.addSuccess(map);
        return response;
    }

    @Override
    public ResponseBean delectRead(String parameter, Integer userID) {
        ResponseBean response = new ResponseBean();
        JSONObject parseObject = JSONObject.parseObject(parameter);

        JSONArray message = parseObject.getJSONArray("id");
        Integer[] messageListID = message.toArray(new Integer[]{});
        for (Integer id : messageListID) {
            Message mes= new Message();
                    mes.setId(id);
                    mes.setReadStatus("1");
                    mes.setUpdateDate(LocalDateTime.now());
                    mes.setUpdateUser(userID);
                    messageMapper.updateById(mes);
        }
                response.addSuccess("成功");
                return response;
    }
    
    /**
     * 房产关联审核通过
     * @param paramsMap
     *         communityId 小区ID
     *         taUserVerifyId  审核ID
     *         createUserId 创建人ID
     */
    @Override
    public void estateRelateVerifyPassed(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        
        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.ESTATE_RELATE_VERIFY_PASSED);
        tpMessage.setAdviceType(Constant.SMS_NOTIFICATION);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.ESTATE_RELATE_VERIFY_PASSED);
        
        tpMessage.setMessageContent(tdModel.getModelContent());
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_READ);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        //插入消息表
        messageMapper.insert(tpMessage);
        //发送短信给客户，先查询出手机号码
        TaUser taUser = getUserPhoneByVerifyId(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        sendSMS(taUser.getLoginName(),Constant.ESTATE_RELATE_VERIFY_PASSED_SMS);
        
    }

	/**
	 * 物业发布公告成功
	 * @param paramsMap
	 * communityId 小区ID
	 * createUserId 创建人ID
	 * announcementId 发布的公告ID
	 */
	@Override
	public void estateServiceAnnouncementSuccess(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

        // 查出当前小区所有的人
        QueryWrapper<TaUserVerify> queryTaUserVerify = new QueryWrapper<>();
        queryTaUserVerify.eq("community_id",Integer.valueOf(paramsMap.get("communityId").toString()));
        queryTaUserVerify.eq("verify_status",Constant.VERIFY_STATUS);
        List<TaUserVerify> userList= taUserVerifyMapper.selectList(queryTaUserVerify);
        List<Message> messageList = new ArrayList<Message>();
        // 推消息
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.ESTATE_SERVICE_ANNOUNCEMENT_SUCCESS);
        for (TaUserVerify userVerify:userList) {
            //保存消息表
            Message tpMessage = new Message();
            tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
            tpMessage.setMessageType(Constant.ESTATE_SERVICE_ANNOUNCEMENT_SUCCESS);
            tpMessage.setAdviceType(Constant.FORUM_NEWS);
            tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
            tpMessage.setUuid(userVerify.getId());
            tpMessage.setUuidType(Constant.UUID_TYPE_APP);
            tpMessage.setSource(Constant.SOURCE_PROP);
            tpMessage.setMessageContent(tdModel.getModelContent());
            tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
            tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
            tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
            tpMessage.setCreateDate(LocalDateTime.now());
            tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("announcementId").toString()));
            tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_ANNOUNCEMENT);
            messageList.add(tpMessage);
        }
        messageMapper.batchList(messageList);
	}
	
	/**
	 * 物业发布活动成功
	 * @param paramsMap
	 *         communityId 小区ID
	 *         taUserVerifyId  审核ID
	 *         createUserId 创建人ID
	 *         activityId 发布的公告ID
	 */
	@Override
	public void estateServiceActivitySuccess(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

        // 查出当前小区所有的人
        QueryWrapper<TaUserVerify> queryTaUserVerify = new QueryWrapper<>();
        queryTaUserVerify.eq("community_id",Integer.valueOf(paramsMap.get("communityId").toString()));
        queryTaUserVerify.eq("verify_status",Constant.VERIFY_STATUS);
        List<TaUserVerify> userList= taUserVerifyMapper.selectList(queryTaUserVerify);
        List<Message> messageList = new ArrayList<Message>();
        TdModel tdModel = getModelByMessageType(Constant.ESTATE_SERVICE_ACTIVITY_SUCCESS);
        for (TaUserVerify userVerify:userList){
		//保存消息表
		Message tpMessage = new Message();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.ESTATE_SERVICE_ACTIVITY_SUCCESS);
		tpMessage.setAdviceType(Constant.FORUM_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(userVerify.getId());
		tpMessage.setUuidType(Constant.UUID_TYPE_APP);
		tpMessage.setSource(Constant.SOURCE_PROP);
		//获取消息内容
		tpMessage.setMessageContent(tdModel.getModelContent());
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(LocalDateTime.now());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("activityId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_ACTIVITY);
            messageList.add(tpMessage);
        }
		messageMapper.batchList(messageList);
	}
	
	/**
	 * 话题被回复
	 * @param paramsMap
	 *         communityId 小区ID
	 *         taUserVerifyId  审核ID
	 *         createUserId 创建人ID
	 *         propName 物业姓名
	 *         content 回复内容
	 *         transactionId 话题ID
	 */
	@Override
	public void threadReply(Map<String, Object> paramsMap) {
		if (null == paramsMap){
			return;
		}

		//保存消息表
		Message tpMessage = new Message();
		tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
		tpMessage.setMessageType(Constant.THREAD_REPLY);
		tpMessage.setAdviceType(Constant.FORUM_NEWS);
		tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
		tpMessage.setUuid(Integer.valueOf(paramsMap.get("userID").toString()));
		tpMessage.setUuidType(paramsMap.get("uuidType").toString());
		tpMessage.setSource(Constant.SOURCE_PROP);
		//获取消息内容
		TdModel tdModel = getModelByMessageType(Constant.THREAD_REPLY);
		String content = tdModel.getModelContent().replace("{name}",paramsMap.get("propName").toString()).replace("{content}",paramsMap.get("content").toString());
		tpMessage.setMessageContent(content);
		tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
		tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
		tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
		tpMessage.setCreateDate(LocalDateTime.now());
		tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("transactionId").toString()));
		tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TRANSACTION);
		messageMapper.insert(tpMessage);
	
	}
	
	/**
	 * 房产关联审核不通过
	 * @param paramsMap
	 *         communityId 小区ID
	 *         taUserVerifyId  审核ID
	 *         createUserId 创建人ID
	 */
    @Override
    public void estateRelateVerifyRejected(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.ESTATE_RELATE_VERIFY_REJECTED);
        tpMessage.setAdviceType(Constant.SMS_NOTIFICATION);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        // 获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.ESTATE_RELATE_VERIFY_REJECTED);
        tpMessage.setMessageContent(tdModel.getModelContent());
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_READ);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        //维护消息
        messageMapper.insert(tpMessage);
        //发送短信给客户，先查询出手机号码
        TaUser taUser = getUserPhoneByVerifyId(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        sendSMS(taUser.getLoginName(),Constant.ESTATE_RELATE_VERIFY_REJECTED_SMS);

    }

    /**
     * 活动报名后被物业后台删除
     * communityId:小区id
     * taUserVerifyId：房产ID
     * cause：活动删除原因
     * createUserId：创建人
     *
     * @param paramsMap
     */
    @Override
    public void ctivityJoinedDeleteByEstateService(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.ACTIVITY_JOINED_DELETE_BY_ESTATE_SERVICE);
        tpMessage.setAdviceType(Constant.FORUM_NEWS);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.ACTIVITY_JOINED_DELETE_BY_ESTATE_SERVICE);
        String content = tdModel.getModelContent().replace("{cause}",paramsMap.get("cause").toString());
        tpMessage.setMessageContent(content);
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("activityId").toString()));
        tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_ACTIVITY);
        messageMapper.insert(tpMessage);
    }

    /**
     * 活动被作废后,批量推消息
     * activityId:活动id
     * communityId:小区ID
     * cause:作废原因
     * createUserId:创建人
     *
     * @param paramsMap
     */
    @Override
    public void activityCancelled(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        // 查询此活动的所有报名人员
        QueryWrapper<TpActivitySignUp> queryWrapper= new  QueryWrapper<>();
        queryWrapper.eq("community_id",paramsMap.get("communityId").toString());
        queryWrapper.eq("activity_id",Integer.valueOf(paramsMap.get("activityId").toString()));
        List<TpActivitySignUp> tpActivitySignUpList= tpActivitySignUpMapper.selectList(queryWrapper);
        List<Message> arrayList = new ArrayList<Message>();

            tpActivitySignUpList.stream().forEach(tpActivitySignUp -> {
                //保存消息表
                Message tpMessage = new Message();
                tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
                tpMessage.setMessageType(Constant.ACTIVITY_CANCELLED);
                tpMessage.setAdviceType(Constant.FORUM_NEWS);
                tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
                tpMessage.setUuid(tpActivitySignUp.getTaUserId());
                tpMessage.setUuidType(Constant.UUID_TYPE_APP);
                tpMessage.setSource(Constant.SOURCE_PROP);
                //获取消息内容
                TdModel tdModel = getModelByMessageType(Constant.ACTIVITY_CANCELLED);
                String content = tdModel.getModelContent().replace("{activityTitle}", paramsMap.get("activityTitle").toString());
                tpMessage.setMessageContent(content);
                tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
                tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
                tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
                tpMessage.setCreateDate(LocalDateTime.now());
                tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("activityId").toString()));
                tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_ACTIVITY);
                arrayList.add(tpMessage);
            });
            if( 0<tpActivitySignUpList.size()) {
                messageMapper.batchList(arrayList);
            }
    }

    /**话题被作废后推消息
     * communityId:小区ID
     * taUserVerifyId：房产ID
     * transactionTitle：话题标题
     * createUserId：创建人
     * transactionId：帖子ID
     * @param paramsMap
     */
    @Override
    public void threadCancelled(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.THREAD_CANCELLED);
        tpMessage.setAdviceType(Constant.FORUM_NEWS);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.THREAD_CANCELLED);
        String content = tdModel.getModelContent().replace("{transactionTitle}",paramsMap.get("transactionTitle").toString());
        tpMessage.setMessageContent(content);
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("transactionId").toString()));
        tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TRANSACTION);
        messageMapper.insert(tpMessage);
    }

    /**
     * 工单被拒绝后，推消息
     * communityId：小区ID
     * taUserVerifyId：房产ID
     * refuseCount：拒绝内容
     * ticketId：工单ID
     * createUserId：创建人
     *
     * @param paramsMap
     */
    @Override
    public void ticketRejected(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.TICKET_REJECTED);
        tpMessage.setAdviceType(Constant.TICKET_NEWS);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.TICKET_REJECTED);
        String content = tdModel.getModelContent().replace("{refuseCount}",paramsMap.get("refuseCount").toString());
        tpMessage.setMessageContent(content);
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
        tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
        messageMapper.insert(tpMessage);
    }

    /**
     * 工单被受理后，推消息
     * communityId：小区ID
     * taUserVerifyId：房产ID
     * ticketId：工单ID
     *
     * @param paramsMap
     */
    @Override
    public void ticketDistributed(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }

        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.TICKET_DISTRIBUTED);
        tpMessage.setAdviceType(Constant.TICKET_NEWS);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("userID").toString()));
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.TICKET_DISTRIBUTED);
        if (null != paramsMap.get("state").toString()&&paramsMap.get("state").toString().equals("prop")){
            // 此处为了推物业端消息通知
            tpMessage.setMessageContent("工单“" + paramsMap.get("ticketTitle").toString() + "”已被分配给您，点击查看并处理");
            tpMessage.setUuidType(Constant.UUID_TYPE_PROP);
        }else {
            tpMessage.setUuidType(Constant.UUID_TYPE_APP);
            String content = tdModel.getModelContent();
            tpMessage.setMessageContent(content);
        }
        tpMessage.setSource(Constant.SOURCE_PROP);
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
        tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
        messageMapper.insert(tpMessage);
    }

    /**
     * 工单处理结果推消息
     * communityId：小区ID
     * taUserVerifyId：房产ID
     * ticketResult：推送结果
     * ticketId：工单ID
     * createUserId：创建人
     * @param paramsMap
     */
    @Override
    public void ticketSubmitResult(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.TICKET_SUBMIT_RESULT);
        tpMessage.setAdviceType(Constant.TICKET_NEWS);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.TICKET_SUBMIT_RESULT );
        String content = tdModel.getModelContent().replace("{ticketResult}",paramsMap.get("ticketResult").toString());
        tpMessage.setMessageContent(content);
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
        tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
        messageMapper.insert(tpMessage);
    }


    /**
     * 回复工单 物业—> app
     * communityId:小区ID
     *taUserVerifyId:房产
     * createUserId：创建人
     * ticketId：工单ID
     *
     * @param paramsMap
     */
    @Override
    public void ticketReply(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.TICKET_REPLY);
        tpMessage.setAdviceType(Constant.TICKET_NEWS);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.TICKET_REPLY );
        String content = tdModel.getModelContent().replace("{replyCount}",paramsMap.get("replyCount").toString());
        tpMessage.setMessageContent(content);
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
        tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
        messageMapper.insert(tpMessage);
    }

    /**
     * 商家回复App
     *communityId：小区ID
     *taUserVerifyId：房产ID
     * replyCount：回复内容
     * createUserId：创建人ID
     * shopId:商铺ID
     * @param paramsMap
     */
    @Override
    public void shopReviewReply(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.SHOP_REVIEW_REPLY);
        tpMessage.setAdviceType(Constant.OTHER_NEWS);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.SHOP_REVIEW_REPLY );
        String content = tdModel.getModelContent().replace("{replyCount}",paramsMap.get("replyCount").toString());
        tpMessage.setMessageContent(content);
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("shopId").toString()));
        tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_SHOP);
        messageMapper.insert(tpMessage);
    }
    /**
     * 房产审核
     * communityId:小区ID
     * taUserVerifyId:房产
     * createUserId：创建人
     * ticketId：工单ID
     *
     * @param paramsMap
     */
    @Override
    public void customerSubmitVerify(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.TICKET_REPLY);
        tpMessage.setAdviceType(Constant.TICKET_NEWS);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.TICKET_REPLY );
        String content = tdModel.getModelContent().replace("{replyCount}",paramsMap.get("replyCount").toString());
        tpMessage.setMessageContent(content);
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("ticketId").toString()));
        tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_TICKET);
        messageMapper.insert(tpMessage);
    }

    /**
     * 收费组推消息
     * @param paramsMap
     */
    @Override
    public void publishBill(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        //保存消息表
        Message tpMessage = new Message();
        tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
        tpMessage.setMessageType(Constant.PUBLISH_BILL);
        tpMessage.setAdviceType(Constant.PROPERTY_NEWS);
        tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
        tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
        tpMessage.setUuidType(Constant.UUID_TYPE_APP);
        tpMessage.setSource(Constant.SOURCE_PROP);
        //获取消息内容
        TdModel tdModel = getModelByMessageType(Constant.PUBLISH_BILL );
        String content = tdModel.getModelContent();
        tpMessage.setMessageContent(content);
        tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
        tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
        tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
        tpMessage.setCreateDate(LocalDateTime.now());
        tpMessage.setMessageUuid(Integer.valueOf(paramsMap.get("billID").toString()));
        tpMessage.setMessageUuidType(Constant.MESSAGE_UUID_TYPE_BILL);
        messageMapper.insert(tpMessage);
    }

    /**
	 * 发送短信
	 * @param phone
	 * @param smsCode
	 */
	private void sendSMS(String phone, String smsCode) {
        RestTemplate restTemplate = new RestTemplate();
        HttpHeaders headers = new HttpHeaders();
        MediaType type = MediaType.parseMediaType("application/json; charset=UTF-8");
        headers.setContentType(type);
        headers.add("Accept", MediaType.APPLICATION_JSON.toString());
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("code",smsCode);
        jsonObject.put("tel",phone);
        HttpEntity<String> formEntity = new HttpEntity<String>(jsonObject.toJSONString(), headers);
	    ResponseEntity<String> stringResponseEntity = restTemplate.postForEntity(Constant.REQUEST_URL, formEntity, String.class);
	    log.info("发送短信结果-> {}",stringResponseEntity.getBody());
    }
    
    /**
     * 根据审核id获取用户信息
     * @param userVerifyId
     * @return
     */
    private TaUser getUserPhoneByVerifyId(Integer userVerifyId) {
        TaUserVerify taUserVerify = taUserVerifyMapper.selectById(userVerifyId);
        return taUserMapper.selectById(taUserVerify.getUserId());
    }

    /**消息12条
     *communityId:小区
     * taUserVerifyId:房产ID
     * createUserId:创建人
     * @param paramsMap
     */
    @Override
    public void systemMessage(Map<String, Object> paramsMap) {
        if (null == paramsMap){
            return;
        }
        // 15条消息数据
        String[] messageArr= new messagePush().messagePushAll();
        for (String count : messageArr) {
            //保存消息表
            Message tpMessage = new Message();
            tpMessage.setCommunityId(Integer.valueOf(paramsMap.get("communityId").toString()));
            tpMessage.setMessageType(Constant.SYSTEM_MESSAGE_TYPE);
            tpMessage.setAdviceType(Constant.SYS_NEWS);
            tpMessage.setModelType(Constant.MODEL_TYPE_NEWS.toString());
            tpMessage.setUuid(Integer.valueOf(paramsMap.get("taUserVerifyId").toString()));
            tpMessage.setUuidType(Constant.UUID_TYPE_APP);
            tpMessage.setSource(Constant.SOURCE_PROP);
            tpMessage.setMessageContent(count);
            tpMessage.setStatus(Constant.STATUS_EFFECTIVE);
            tpMessage.setReadStatus(Constant.READ_STATUS_UNREAD);
            tpMessage.setCreateUser(Integer.valueOf(paramsMap.get("createUserId").toString()));
            tpMessage.setCreateDate(LocalDateTime.now());
            //插入消息表
            messageMapper.insert(tpMessage);
        }
    }
    
    /**
     * 根据审核类型获取消息内容
     * @param messageType
     * @return
     */
    private TdModel getModelByMessageType(String messageType) {
        QueryWrapper<TdModel> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("message_type",messageType);
        return tdModelMapper.selectOne(queryWrapper);
    }
}
