package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.commom.utils.BeanTools;
import com.community.huiju.dao.*;
import com.community.huiju.event.MessageEvent;
import com.community.huiju.model.*;
import com.community.huiju.service.ITpActivitySignUpService;
import com.community.huiju.vo.ActivitySignUpVO;
import com.google.common.collect.Maps;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 物业web端活动报名表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2019-01-03
 */
@Service
public class TpActivitySignUpServiceImpl extends ServiceImpl<TpActivitySignUpMapper, TpActivitySignUp> implements ITpActivitySignUpService {

    @Autowired
    private TpActivityMapper tpActivityMapper;

    @Autowired
    private TpActivitySignUpMapper tpActivitySignUpMapper;

    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private TpBuildingOwnerInfoMapper tpBuildingOwnerInfoMapper;

    @Autowired
    private TaSysRoleMapper taSysRoleMapper;

    @Autowired
    private TaUserVerifyMapper taUserVerifyMapper;

    @Autowired
    private ApplicationContext applicationContext;

    @Override
    public ResponseBean getSignUpUser(String parameter) {
        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);
        Integer signUpId = jsonObject.getInteger("signUpId");
        Integer activityId = jsonObject.getInteger("id");
        Integer pageNum = jsonObject.getInteger("pageNum");
        Integer pageSize = jsonObject.getInteger("pageSize");
        String userName = jsonObject.getString("userName");
        String phone = jsonObject.getString("phone");

        TpActivity tpActivity = tpActivityMapper.selectById(activityId);
        // 判断是不是从消息也点击的
        if (null == signUpId) {
            if (null == tpActivity) {
                responseBean.addError("活动不存在!");
                return responseBean;
            }
        }

        Page<TpActivitySignUp> page = new Page<>();
        page.setCurrent(null == pageNum ? 0 : pageNum);
        page.setSize(null == pageSize ? 10 : pageSize);
        page.setDesc("sign_up_time");

        IPage<TpActivitySignUp> signUpIPage = tpActivitySignUpMapper.listQuery(page, userName, phone, activityId,signUpId);

        List<TpActivitySignUp> tpActivitySignUpList = signUpIPage.getRecords();
        // 数据包装填充
        List<ActivitySignUpVO> activitySignUpVOS = tpActivitySignUpList.stream().map(e->{
            ActivitySignUpVO activitySignUpVO = new ActivitySignUpVO();
            BeanTools.copyProperties(e, activitySignUpVO);

            //根据房产ID-去查询用户ID
            TaUserVerify taUserVerify= taUserVerifyMapper.selectById(e.getTaUserId());
            TaUser taUser = taUserMapper.selectById(taUserVerify.getUserId());

            activitySignUpVO.setUserName(taUser.getUserName());
            activitySignUpVO.setPhone(taUser.getLoginName());

            activitySignUpVO.setRoleName(e.getUserRole());
            activitySignUpVO.setAddress(e.getAddress());

            return activitySignUpVO;
        }).collect(Collectors.toList());

        Map<String, Object> map = Maps.newHashMap();
        map.put("list", activitySignUpVOS);
        map.put("total", signUpIPage.getTotal());
        map.put("pageNum", signUpIPage.getCurrent());
        map.put("pageSize", signUpIPage.getSize());

        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean deleteSignUp(Integer id, String parameter,UserElement userElement) {
        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);
        Boolean sendSMS = jsonObject.getBoolean("sendSMS");

        TpActivitySignUp tpActivitySignUp = tpActivitySignUpMapper.selectById(id);
        if (null == tpActivitySignUp) {
            responseBean.addError("该记录不存在!");
            return responseBean;
        }

        TaUserVerify taUserVerify = taUserVerifyMapper.selectById(tpActivitySignUp.getTaUserId());
        if (null == taUserVerify) {
            responseBean.addError("APP端 用户不存在!");
            return responseBean;
        }

        tpActivitySignUpMapper.deleteById(tpActivitySignUp);
        TpActivity tpActivity = tpActivityMapper.selectById(tpActivitySignUp.getActivityId());
        if (tpActivity.getSignUpCount().intValue() > 0) {
            tpActivity.setSignUpCount(tpActivity.getSignUpCount() - 1);
            tpActivityMapper.updateById(tpActivity);
        }

        // 发送短信
        // TODO 删除成功后, 发送短信通知用户
        if (sendSMS) {
            // 开始发送

        }
        // 推送消息
        Map<String, Object> mapApp = new HashMap<>();
        mapApp.put("communityId", tpActivitySignUp.getCommunityId());
        mapApp.put("activityId",tpActivitySignUp.getActivityId() );
        mapApp.put("cause", "请联系物业咨询具体原因");
        mapApp.put("createUserId", userElement.getId());
        mapApp.put("taUserVerifyId", tpActivitySignUp.getTaUserId());
        applicationContext.publishEvent(new MessageEvent(mapApp, Constant.ACTIVITY_JOINED_DELETE_BY_ESTATE_SERVICE, mapApp));
        responseBean.addSuccess("操作成功!");
        return responseBean;
    }
}
