package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.dao.*;
import com.community.huiju.event.MessageEvent;
import com.community.huiju.lisenter.MessageLisenter;
import com.community.huiju.model.*;
import com.community.huiju.service.TpAnnouncementService;
import com.community.huiju.vo.AnnouncementTable;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.formula.functions.T;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.*;
import java.util.stream.Collectors;

/**
 * version V1.0
 * class_name: $METHOD_NAME$
 * param: $METHOD_PARAM$
 * describe: TODO
 * creat_user:fannaixi
 * creat_time: 2018/12/28
 **/
@Slf4j
@Transactional
@Service
public class TpAnnouncementServiceImpl extends ServiceImpl<TpAnnouncementMapper, TpAnnouncement> implements TpAnnouncementService {

@Autowired
private  TpAnnouncementMapper tpAnnouncementMapper;

    @Autowired
    private TdImagesMapper imagesMapper;

    @Autowired
    private UserMapper userMapper;

    @Autowired
    private MessageMapper messageMapper;

    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private TaUserVerifyMapper taUserVerifyMapper;

    @Resource
    private ApplicationContext applicationContext;

    @Override
    public ResponseBean tpAnnouncemenList(String paramets, Integer CommunityId) {
        ResponseBean responseBean = new ResponseBean();

        TpAnnouncement   tpAnnouncement= JSONObject.parseObject(paramets, TpAnnouncement.class);
        tpAnnouncement.setCommunityId(CommunityId);
        JSONObject jsonobject = JSONObject.parseObject(paramets);
        Integer pageNum = jsonobject.getInteger("pageNum");
        Integer announcementNumber = jsonobject.getInteger("announcementNumber");
        Integer pageSize = jsonobject.getInteger("pageSize");
        tpAnnouncement.setId(announcementNumber);
        // 分页
        Page<TpBuildingOwnerInfo> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
        // page.setDesc("sort", "create_date");

        IPage<TpAnnouncement> pageInfo = tpAnnouncementMapper.getAnnouncements(page,tpAnnouncement);
        List<TpAnnouncement> tpAnnouncementList = pageInfo.getRecords();

        List<AnnouncementTable> tableList = tpAnnouncementList.stream().map(e->{
            AnnouncementTable announcementTable = new AnnouncementTable();
            BeanUtils.copyProperties(e, announcementTable);
            //创建人
            String  updateDateName= userMapper.selectByIdUserName(e.getUpdateUser());
            //修改人
            String  createUserName= userMapper.selectByIdUserName(e.getCreateUser());
            announcementTable.setCreateUserName(createUserName);
            announcementTable.setUpdateDateName(updateDateName);
            return announcementTable;
        }).collect(Collectors.toList());

        Map<String, Object> map = Maps.newHashMap();
        map.put("list", tableList);
        map.put("total", pageInfo.getTotal());
        map.put("pageNum", pageInfo.getCurrent());
        map.put("pageSize", pageInfo.getSize());
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean addAnnouncement(String paramets, Integer communityId,Integer userId) {
        ResponseBean response = new ResponseBean();
        JSONObject jsonobject = JSONObject.parseObject(paramets);
        TpAnnouncement tpAnnouncement = JSONObject.parseObject(paramets, TpAnnouncement.class);
        tpAnnouncement.setCommunityId(communityId);
        tpAnnouncement.setCreateDate(new Date());
        tpAnnouncement.setCreateUser(userId);
        tpAnnouncement.setViewCount(0);
        JSONArray contentImg = jsonobject.getJSONArray("contentImg");
        String[] contentImgArray = contentImg.toArray(new String[]{});

        if (tpAnnouncement.getAnnouncementTitle() == null) {
            response.addError("标题不能为空");
            return response;
        }
        if (null == tpAnnouncement.getAnnouncementContent() && null == contentImg) {
            response.addError("内容和图片必须填一个");
            return response;
        }
        tpAnnouncementMapper.insert(tpAnnouncement);
        // 推消息
        Map<String,Object> map = new HashMap<>();
        map.put("communityId",String.valueOf(communityId));
        map.put("createUserId",String.valueOf(userId));
        map.put("announcementId",String.valueOf(tpAnnouncement.getId()));
        map.put("announcementTitle",String.valueOf(tpAnnouncement.getAnnouncementTitle()));
        applicationContext.publishEvent(new MessageEvent(tpAnnouncement, Constant.ESTATE_SERVICE_ANNOUNCEMENT_SUCCESS,map));

        for (String img : contentImgArray) {
            TdImages tdImages = new TdImages();
            tdImages.setImageUrl(img);
            tdImages.setType("announcement");
            tdImages.setUuid(tpAnnouncement.getId());
            tdImages.setCreateTime(LocalDateTime.now());
            tdImages.setCreateUser(userId);
            imagesMapper.insert(tdImages);
        }
            return response;
    }
        @Override
        public ResponseBean announcementById(String paramets) {
            ResponseBean response= new ResponseBean<>();
            JSONObject jsonobject = JSONObject.parseObject(paramets);
            Integer   id= jsonobject.getInteger("id");
            TpAnnouncement tpAnnouncement=tpAnnouncementMapper.selectById(id);
            //查询图片
            QueryWrapper<TdImages> queryWrapper = new QueryWrapper<>();
            queryWrapper.lambda().eq(TdImages::getUuid,id);
            queryWrapper.lambda().eq(TdImages::getType,"announcement");
            List<TdImages> studentList = imagesMapper.selectList(queryWrapper);
            HashMap map= new HashMap<>();

            for (TdImages tdImages:studentList){
               tdImages.getImageUrl();
            }
            map.put("tpAnnouncement",tpAnnouncement);
            map.put("studentList",studentList);
            response.addSuccess(map);
            return response;
        }

    @Override
    public ResponseBean updateAnnouncement(String paramets,Integer communityId,Integer userId) {
                  ResponseBean response= new ResponseBean();
         TpAnnouncement tpAnnouncement = JSONObject.parseObject(paramets, TpAnnouncement.class);
         int Status= Integer.parseInt(tpAnnouncement.getStatus());
         if (0!=Status){
                        tpAnnouncement.setCommunityId(communityId);
                        tpAnnouncement.setUpdateUser(userId);
                        tpAnnouncement.setCreateUser(null);
                        //为草稿时不跟新时间
             TpAnnouncement AnnouncementStatus=tpAnnouncementMapper.selectById(tpAnnouncement.getId());
                            tpAnnouncement.setUpdateDate("2".equals(AnnouncementStatus.getStatus())?null:new Date());
                            tpAnnouncement.setUpdateUser("2".equals(AnnouncementStatus.getStatus())?null:userId);
                        tpAnnouncementMapper.updateTpAnnouncement(tpAnnouncement);

        JSONObject parseObject = JSONObject.parseObject(paramets);
        //内容包含多个图转数组
        JSONArray contentImg = parseObject.getJSONArray("contentImg");
        Integer tdImagesUuid = parseObject.getInteger("id");
        String[] contentImgArray = contentImg.toArray(new String[]{});
        //修改图片时删除原来图片
            QueryWrapper<TdImages> queryWrapper = new QueryWrapper<>();
            queryWrapper.lambda().eq(TdImages::getUuid, tdImagesUuid);
            queryWrapper.lambda().eq(TdImages::getType, "announcement");
            imagesMapper.delete(queryWrapper);

            for (String img : contentImgArray) {
                TdImages tdImages = new TdImages();
                tdImages.setImageUrl(img);
                tdImages.setType("announcement");
                tdImages.setUuid(tpAnnouncement.getId());
                tdImages.setCreateTime(LocalDateTime.now());
                tdImages.setCreateUser(userId);
                imagesMapper.insert(tdImages);
            }
        }
        return response;
    }

    @Override
    public ResponseBean deleteAnnouncement(String paramets, Integer communityId, Integer userId) {
        ResponseBean response = new ResponseBean();
        JSONObject parseObject = JSONObject.parseObject(paramets);
        // 作废改为上架和下架status=1为上架0为下架
        String Status= parseObject.getString("status");
        JSONArray announcementIdId = parseObject.getJSONArray("id");
        Integer[] announcementIdArray = announcementIdId.toArray(new Integer[]{});
        for (Integer id : announcementIdArray) {
            TpAnnouncement tpAnnouncement = new TpAnnouncement();
            tpAnnouncement.setId(id);
            tpAnnouncement.setCommunityId(communityId);
            tpAnnouncement.setStatus(Status);
            tpAnnouncementMapper.updateTpAnnouncement(tpAnnouncement);
            //1.5版本维护消息
//            Message message= new Message();
//            message.setStatus("0");
//            message.setAnnouncementId(id);
//            message.setUpdateUser(userId);
//            message.setUpdateDate(LocalDateTime.now());
//            messageMapper.updateMessage(message);
        }
        return response;
    }
}
